fps — boto v2.25.0

### Navigation

- index
- modules |
- next |
- previous |
- boto v2.25.0 »
- API Reference »

# fps

## boto.fps

## boto.fps.connection

class `boto.fps.connection.` `FPSConnection`(*args, **kw)
  `APIVersion` = '2010-08-28'
  `ResponseError`

    alias of `ResponseErrorFactory`

  `cancel`(*args, **kw)

    FPS Cancel API call

    > Cancels an ongoing transaction and puts it in cancelled state.

    Required: TransactionId

  `cancel_subscription_and_refund`(*args, **kw)

    FPS CancelSubscriptionAndRefund API call

    > Cancels a subscription.

    Required: SubscriptionId Complex Amounts: RefundAmount Uses CallerReference, defaults to uuid.uuid4()

  `cancel_token`(*args, **kw)

    FPS CancelToken API call

    > Cancels any token installed by the calling application on its own account.

    Required: TokenId

  `cbui_url`(*args, **kw)
    Generate a signed URL for the Co-Branded service API given arguments as
      payload.

    Required: returnURL+pipelineName Uses CallerReference, defaults to uuid.uuid4()

  `currencycode` = 'USD'
  `fund_prepaid`(*args, **kw)

    FPS FundPrepaid API call

    > Funds the prepaid balance on the given prepaid instrument.

    Required: PrepaidInstrumentId+FundingAmount.Value+SenderTokenId+FundingAmount.CurrencyCode Complex Amounts: FundingAmount Uses CallerReference, defaults to uuid.uuid4()

  `get_account_activity`(*args, **kw)

    FPS GetAccountActivity API call

    > Returns transactions for a given date range.

    Required: StartDate

  `get_account_balance`(*args, **kw)

    FPS GetAccountBalance API call

    Returns the account balance for an account in real time.

  `get_debt_balance`(*args, **kw)

    FPS GetDebtBalance API call

    > Returns the balance corresponding to the given credit instrument.

    Required: CreditInstrumentId

  `get_outstanding_debt_balance`(*args, **kw)

    FPS GetOutstandingDebtBalance API call

    Returns the total outstanding balance for all the credit instruments for the given creditor account.

  `get_payment_instruction`(*args, **kw)

    FPS GetPaymentInstruction API call

    > Gets the payment instruction of a token.

    Required: TokenId

  `get_prepaid_balance`(*args, **kw)

    FPS GetPrepaidBalance API call

    > Returns the balance available on the given prepaid instrument.

    Required: PrepaidInstrumentId

  `get_recipient_verification_status`(*args, **kw)

    FPS GetRecipientVerificationStatus API call

    > Returns the recipient status.

    Required: RecipientTokenId

  `get_subscription_details`(*args, **kw)

    FPS GetSubscriptionDetails API call

    > Returns the details of Subscription for a given subscriptionID.

    Required: SubscriptionId

  `get_token_by_caller`(*args, **kw)

    FPS GetTokenByCaller API call

    > Returns the details of a particular token installed by this calling application using the subway co-branded UI.

    Required: CallerReference OR TokenId

  `get_token_usage`(*args, **kw)

    FPS GetTokenUsage API call

    > Returns the usage of a token.

    Required: TokenId

  `get_tokens`(*args, **kw)

    FPS GetTokens API call

    Returns a list of tokens installed on the given account.

  `get_total_prepaid_liability`(*args, **kw)

    FPS GetTotalPrepaidLiability API call

    Returns the total liability held by the given account corresponding to all the prepaid instruments owned by the account.

  `get_transaction`(*args, **kw)

    FPS GetTransaction API call

    > Returns all details of a transaction.

    Required: TransactionId

  `get_transaction_status`(*args, **kw)

    FPS GetTransactionStatus API call

    > Gets the latest status of a transaction.

    Required: TransactionId

  `get_transactions_for_subscription`(*args, **kw)

    FPS GetTransactionsForSubscription API call

    > Returns the transactions for a given subscriptionID.

    Required: SubscriptionId

  `install_payment_instruction`(*args, **kw)

    FPS InstallPaymentInstruction API call

    > Installs a payment instruction for caller.

    Required: PaymentInstruction+TokenType Uses CallerReference, defaults to uuid.uuid4()

  `pay`(*args, **kw)

    FPS Pay API call

    > Allows calling applications to move money from a sender to a recipient.

    Required: SenderTokenId+TransactionAmount.Value+TransactionAmount.CurrencyCode Complex Amounts: TransactionAmount Uses CallerReference, defaults to uuid.uuid4()

  `refund`(*args, **kw)

    FPS Refund API call

    > Refunds a previously completed transaction.

    Required: TransactionId+RefundAmount.Value+CallerReference+RefundAmount.CurrencyCode Complex Amounts: RefundAmount

  `reserve`(*args, **kw)

    FPS Reserve API call

    > Reserve API is part of the Reserve and Settle API conjunction that serve the purpose of a pay where the authorization and settlement have a timing difference.

    Required: SenderTokenId+TransactionAmount.Value+TransactionAmount.CurrencyCode Complex Amounts: TransactionAmount Uses CallerReference, defaults to uuid.uuid4()

  `settle`(*args, **kw)

    FPS Settle API call

    > The Settle API is used in conjunction with the Reserve API and is used to settle previously reserved transaction.

    Required: ReserveTransactionId+TransactionAmount.Value+TransactionAmount.CurrencyCode Complex Amounts: TransactionAmount

  `settle_debt`(*args, **kw)

    FPS SettleDebt API call

    > Allows a caller to initiate a transaction that atomically transfers money from a sender’s payment instrument to the recipient, while decreasing corresponding debt balance.

    Required: CreditInstrumentId+SettlementAmount.Value+SenderTokenId+SettlementAmount.CurrencyCode Complex Amounts: SettlementAmount Uses CallerReference, defaults to uuid.uuid4()

  `verify_signature`(*args, **kw)

    FPS VerifySignature API call

    > Verify the signature that FPS sent in IPN or callback urls.

    Required: UrlEndPoint+HttpParameters

  `write_off_debt`(*args, **kw)

    FPS WriteOffDebt API call

    > Allows a creditor to write off the debt balance accumulated partially or fully at any time.

    Required: CreditInstrumentId+AdjustmentAmount.Value+AdjustmentAmount.CurrencyCode Complex Amounts: AdjustmentAmount Uses CallerReference, defaults to uuid.uuid4()

### Navigation

- index
- modules |
- next |
- previous |
- boto v2.25.0 »
- API Reference »